@@ -25,8 +25,9 @@ MainWindow::MainWindow(QWidget *parent) :
     readdirs();
     oldfonts("/etc/hildon/theme/colors.config");
     progress3.setValue(20);
-    readgtkrc();
+    readgtkrc("/etc/hildon/theme/");
     progress3.setValue(30);
+    readthemes();
     QRegExp regexer("^\\#[0-9a-fA-F]{6,6}$");
     progress3.setValue(35);
     QRegExp regexer_icon("^[0-9]{2,3}$");
@@ -66,11 +67,12 @@ void MainWindow::oldfonts(QString preset)
 {
 
     QFile file(preset);
+    if (file.exists()) {
     file.open(QFile::ReadOnly);
 
     QTextStream stream ( &file );
     QString line;
-    QHash<QString, QString> variables;
+//    QHash<QString, QString> variables;
     do {
         line = stream.readLine();
 
@@ -124,6 +126,15 @@ void MainWindow::oldfonts(QString preset)
     ui->fontbuttonpressed->setStyleSheet(COLOR_STYLE.arg(variables.value("ButtonTextPressedColor"), variables.value("DefaultBackgroundColor"), variables.value("ButtonTextPressedColor")));
     ui->font8->setText(variables.value("ButtonTextPressedColor"));
     f8=variables.value("ButtonTextPressedColor");
+
+    ui->pushButton->setEnabled(true);
+
+ //   ui->widget->setStyleSheet("background-color: " + variables.value("DefaultBackgroundColor") + ";");
+    } else {
+        QMaemo5InformationBox::information(this, tr("Fatal error! Could not read:") + "<br />" + preset, QMaemo5InformationBox::NoTimeout);
+ //       system("killall theme-customizer");
+        ui->pushButton->setDisabled(true);
+    }
 }
 
 void MainWindow::readdirs()
@@ -141,14 +152,57 @@ void MainWindow::readdirs()
     }
 }
 
-void MainWindow::readgtkrc()
+void MainWindow::readthemes()
 {
-    QFile file2("/etc/hildon/theme/gtk-2.0/gtkrc");
+    ui->theme->clear();
+//    QDir themes("/usr/share/themes");
+
+    QDirIterator iter("/usr/share/themes/", QDir::Files, QDirIterator::Subdirectories);
+    QStringList teemat;
+    while(iter.hasNext())
+    {
+        QString path = iter.next();
+
+        if(path.endsWith(".theme"))
+        {
+            QSettings settings(path, QSettings::IniFormat);
+            settings.beginGroup("Desktop Entry");
+            if (settings.contains("Name"))
+            {
+                QString name = settings.value("Name").toString();
+                // ui->theme->addItem(name);
+                QString themepath = iter.filePath();
+                themepath.remove("index.theme");
+
+                variables.insert(name, themepath);
+                teemat << name;
+            }
+        }
+    }
+
+    teemat.sort();
+    teemat.removeDuplicates();
+    ui->theme->addItems(teemat);
+
+    // let's find out current theme's name and set it selected
+    QSettings settings("/etc/hildon/theme/index.theme", QSettings::IniFormat);
+    settings.beginGroup("Desktop Entry");
+    currenttheme = settings.value("Name").toString();
+    int indeksi = ui->theme->findText(currenttheme);
+    ui->theme->setCurrentIndex(indeksi);
+
+}
+
+void MainWindow::readgtkrc(QString themedir)
+{
+    QString file = themedir + "gtk-2.0/gtkrc";
+    QFile file2(file);
+    if (file2.exists()) {
     file2.open(QFile::ReadOnly);
 
     QTextStream stream2 ( &file2 );
     QString line2;
-    QHash<QString, QString> gtkrc;
+//    QHash<QString, QString> gtkrc;
     do {
         line2 = stream2.readLine();
 
@@ -161,26 +215,31 @@ void MainWindow::readgtkrc()
 
     file2.close();
 
-    QString icontheme;
     icontheme = gtkrc.value("gtk-icon-theme-name ");
     icontheme.remove(QChar('\"'));
     icontheme.remove(QChar(' '));
     icontheme.simplified();
 
-    currenttheme = gtkrc.value("gtk-theme-name ");
-    currenttheme.remove(QChar('\"'));
-    currenttheme.simplified();
+//    currenttheme = gtkrc.value("gtk-theme-name ");
+//    currenttheme.remove(QChar('\"'));
+//    currenttheme.simplified();
 
     int indeksi = ui->Iconset->findText(icontheme);
     ui->Iconset->setCurrentIndex(indeksi);
 
-    ui->label->setText(tr("Current theme: ") + currenttheme + "\n" + tr("Tap to change"));
+    ui->pushButton->setEnabled(true);
+
+    } else {
+        QMaemo5InformationBox::information(this, tr("Fatal error! Could not read:") + "<br />" + file, QMaemo5InformationBox::NoTimeout);
+        ui->pushButton->setDisabled(true);
+        //        system("killall theme-customizer");
+    }
 }
 
 void MainWindow::writeSettings()
 {
     QSettings sett("ThemeCustomizer", "Boxes");
-    QSettings themesett("ThemeCustomizer", currenttheme);
+    QSettings themesett("ThemeCustomizer", " " + currenttheme);
     sett.setValue("snap", ui->Snap->text());
     themesett.setValue("fontsize", ui->FontSize->currentIndex());
     sett.setValue("iconset", ui->Iconset->currentIndex());
@@ -209,7 +268,7 @@ void MainWindow::writeSettings()
 void MainWindow::readSettings()
 {
     QSettings sett("ThemeCustomizer", "Boxes");
-    QSettings themesett("ThemeCustomizer", currenttheme);
+    QSettings themesett("ThemeCustomizer", " " + currenttheme);
     int icons = sett.value("icons").toInt();
 //    int transitions = themesett.value("transitions").toInt();
     int snap = sett.value("snap").toInt();
@@ -241,7 +300,9 @@ void MainWindow::readSettings()
     }
 
     if ( !fontsizestring.isEmpty() ) {
-    ui->FontSize->setCurrentIndex(fontsize);
+        ui->FontSize->setCurrentIndex(fontsize);
+    } else {
+        ui->FontSize->setCurrentIndex(0);
     }
 
     if ( appsize > 15 ) {
@@ -270,10 +331,25 @@ void MainWindow::readSettings()
     if ( !opacitystring_top.isEmpty() ) {
     ui->Opacity_top->setText(opacitystring_top);
     ui->horizontalSlider_5->setValue(opacity_top);
-} else {
+    } else {
     ui->Opacity_top->setText("255");
     ui->horizontalSlider_5->setValue(255);
-}
+    }
+
+    // let's find out current theme's wallpapers
+    if (QFile::exists(themepath + "backgrounds/theme_bg.desktop")) {
+        QSettings settings(themepath + "backgrounds/theme_bg.desktop", QSettings::IniFormat);
+        settings.beginGroup("Desktop Entry");
+        wall1 = settings.value("X-File1").toString();
+        wall2 = settings.value("X-File2").toString();
+        wall3 = settings.value("X-File3").toString();
+        wall4 = settings.value("X-File4").toString();
+        ui->radioButton->setChecked(true);
+        ui->radioButton->setEnabled(true);
+    } else {
+        ui->radioButton_2->setChecked(true);
+        ui->radioButton->setDisabled(true);
+    }
 
 }
 
@@ -373,14 +449,14 @@ void MainWindow::runscript(QString command)
                 progress.setValue(2);
                 progress.setValue(3);
                 progress.setValue(4);
+                sleep(1);
                 QStringList systemcommand;
-                systemcommand << "saveasnew" << themename << themedir;
+                systemcommand << "saveasnew" << themename << themedir << icontheme;
                 QProcess *muoks0 = new QProcess(this);
                 muoks0->start("/sbin/launchcustomizer", systemcommand);
                 muoks0->waitForFinished();
                 progress.setValue(5);
                 saveasnew = "0";
-                readgtkrc();
     }
 
     if ( command == "saveonly" ) {
@@ -393,28 +469,37 @@ void MainWindow::runscript(QString command)
         progress.setValue(35);
         oldfonts("/etc/hildon/theme/colors.config");
         progress.setValue(40);
-        readgtkrc();
+        readthemes();
+        readgtkrc("/etc/hildon/theme/");
         progress.setValue(45);
+        writeSettings();
         progress.setValue(50);
         readSettings();
         progress.setValue(55);
         progress.setValue(60);
         progress.setValue(70);
         progress.setValue(80);
-        writeSettings();
         progress.setValue(90);
         progress.cancel();
         QMaemo5InformationBox::information(this, tr("New theme saved!"), QMaemo5InformationBox::DefaultTimeout);
         return;
 
     }
+
+    QStringList systemcommand;
+    systemcommand.clear();
+    systemcommand << "settheme" << themepath;
+    QProcess *muoksteema = new QProcess(this);
+    muoksteema->start("/sbin/launchcustomizer", systemcommand);
+    muoksteema->waitForFinished();
+
     writeSettings();
 
     progress.setLabelText(tr("Creating backups..."));
     progress.setValue(6);
     progress.setValue(7);
     progress.setValue(8);
-    QStringList systemcommand;
+    systemcommand.clear();
     systemcommand << "createbackups";
     QProcess *muoks1 = new QProcess(this);
     muoks1->start("/sbin/launchcustomizer", systemcommand);
@@ -423,9 +508,7 @@ void MainWindow::runscript(QString command)
     clean();
     clean();
 
-//        QMaemo5InformationBox::information(this, tr("Setting up font family..."), 1);
     progress.setLabelText(tr("Setting up font family..."));
-//        sleep(2);
     progress.setValue(12);
     progress.setValue(14);
     progress.setValue(16);
@@ -437,9 +520,7 @@ void MainWindow::runscript(QString command)
     muoks2->waitForFinished();
     progress.setValue(20);
 
-//        QMaemo5InformationBox::information(this, tr("Setting up font sizes..."), 1);
     progress.setLabelText(tr("Setting up font sizes..."));
-//        sleep(2);
     progress.setValue(22);
     progress.setValue(24);
     progress.setValue(26);
@@ -451,9 +532,7 @@ void MainWindow::runscript(QString command)
     muoks3->waitForFinished();
     progress.setValue(30);
 
-//        QMaemo5InformationBox::information(this, tr("Setting up font colors..."), 1);
     progress.setLabelText(tr("Setting up font colors..."));
-//        sleep(2);
     progress.setValue(32);
     progress.setValue(34);
     progress.setValue(36);
@@ -465,9 +544,7 @@ void MainWindow::runscript(QString command)
     muoks4->waitForFinished();
     progress.setValue(40);
 
-//        QMaemo5InformationBox::information(this, tr("Setting up icon theme..."), 1);
     progress.setLabelText(tr("Setting up icon theme..."));
-//        sleep(2);
     progress.setValue(42);
     progress.setValue(44);
     progress.setValue(46);
@@ -510,9 +587,28 @@ void MainWindow::runscript(QString command)
     muoks7->waitForFinished();
     progress.setValue(70);
 
+    if (ui->radioButton->isChecked()) {
+        QString command;
+
+        QProcess *wallpros1 = new QProcess(this);
+        command = "gconftool -s --type string /apps/osso/hildon-desktop/views/1/bg-image " + wall1;
+        wallpros1->start(command);
+
+        QProcess *wallpros2 = new QProcess(this);
+        command = "gconftool -s --type string /apps/osso/hildon-desktop/views/2/bg-image " + wall2;
+        wallpros2->start(command);
+
+        QProcess *wallpros3 = new QProcess(this);
+        command = "gconftool -s --type string /apps/osso/hildon-desktop/views/3/bg-image " + wall3;
+        wallpros3->start(command);
+
+        QProcess *wallpros4 = new QProcess(this);
+        command = "gconftool -s --type string /apps/osso/hildon-desktop/views/4/bg-image " + wall4;
+        wallpros4->start(command);
+    }
+
     int opasity = ui->Opacity->text().toInt();
     int opasity_top = ui->Opacity_top->text().toInt();
-//       QMaemo5InformationBox::information(this, tr("Setting up widget opacities..."), 1);
     progress.setLabelText(tr("Setting up widget opacities..."));
     progress.setValue(72);
     progress.setValue(74);
@@ -548,49 +644,30 @@ void MainWindow::runscript(QString command)
 
         progress.setLabelText(tr("Restarting services..."));
         progress.setValue(90);
-  //      sleep(1);
-  //      QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."), QMaemo5InformationBox::DefaultTimeout);
-        system("/usr/sbin/dsmetool -k /usr/bin/hildon-home");
-        // sleep(1);
-        progress.setValue(92);
         system("killall hildon-status-menu");
-        // sleep(1);
+        progress.setValue(92);
+        system("/usr/sbin/dsmetool -k /usr/bin/hildon-home");
         system("ps ax | grep -v grep | grep osso-abook-home-applet > /dev/null && killall osso-abook-home-applet && sleep 2 &&  ps ax | grep -v grep | grep osso-abook-home-applet || /usr/sbin/dsmetool -t /usr/bin/osso-abook-home-applet");
         progress.setValue(93);
-        // sleep(1);
         system("killall systemui");
         progress.setValue(94);
-        // sleep(1);
         system("killall browser browserd");
         progress.setValue(95);
-        // sleep(1);
         system("killall rtcom-messaging-ui");
         progress.setValue(96);
-        // sleep(1);
         system("killall rtcom-call-ui");
         progress.setValue(97);
-        // sleep(1);
         system("/usr/sbin/dsmetool -t /usr/bin/hildon-home; sleep 2");
         progress.setValue(98);
-   //     sleep(4);
-        // systemcommand.clear();
-        // systemcommand << "restartservices";
-	// QProcess *muoks8 = new QProcess(this);
-	// muoks8->start("/sbin/launchcustomizer", systemcommand);
-	// muoks8->waitForFinished();
         progress.setValue(99);
         QMaemo5InformationBox::information(this, tr("Theme customizations applied!") +  "<br /><br />" + tr("Restart the device to reload all theme elements and make all changes visible."), QMaemo5InformationBox::NoTimeout);
         progress.cancel();
-//	sleep(2);
-//        system("killall theme-customizer");
 
     } else {
 
     system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
     system("/sbin/launchcustomizer rebootnow");
     progress.setValue(99);
- //   progress.cancel();
-    // oldfonts();
 
 }
 
@@ -837,7 +914,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-63<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-64<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -1083,6 +1160,8 @@ void MainWindow::savetheme()
     themedir = themedir.remove(QChar(' '));
     themedir = themedir.simplified();
     themedir = themedir.toLower();
+    themedir[0] = themedir[0].toUpper();
+    themename[0] = themename[0].toUpper();
     QDir file;
     file = "/opt/usr/share/themes/" + themedir;
 
@@ -1156,6 +1235,7 @@ void MainWindow::deletetheme()
         muoks0->start("/sbin/launchcustomizer", systemcommand);
         muoks0->waitForFinished();
         QMaemo5InformationBox::information(this, tr("Theme deleted."), QMaemo5InformationBox::DefaultTimeout);
+        readthemes();
         ManThemeWin = new managethemes(this);
         connect(ManThemeWin->ui->deletebutton, SIGNAL(clicked()), this, SLOT(deletetheme()));
         ManThemeWin->show();
@@ -1203,33 +1283,16 @@ void MainWindow::on_actionImport_theme_triggered()
     progress2.show();
 }
 
-void MainWindow::on_label_clicked()
+void MainWindow::on_theme_currentIndexChanged(int index)
 {
-    QProcess *process2 = new QProcess(this);
-//    connect(process2, SIGNAL(finished(int)), this, SLOT(process2Finished(int)));
-    process2->start("/usr/bin/personalisation_app");
-    process2->waitForFinished();
-    QString varattu3;
-    varattu3 = tr("Reading settings");
-    progress3.setWindowModality(Qt::WindowModal);
-    progress3.setWindowTitle(varattu3);
-    progress3.setCancelButton(0);
-    progress3.setValue(0);
-    progress3.show();
-    progress3.setValue(5);
+    currenttheme = ui->theme->currentText();
+    if (currenttheme.isEmpty())
+        return;
+
+    themepath = variables.value(ui->theme->currentText());
     readdirs();
-    oldfonts("/etc/hildon/theme/colors.config");
-    progress3.setValue(20);
-    readgtkrc();
-    progress3.setValue(30);
-    progress3.setValue(35);
-    progress3.setValue(45);
-    progress3.setValue(50);
-    progress3.setValue(60);
-    progress3.setValue(70);
-    progress3.setValue(80);
+    oldfonts(themepath + "colors.config");
+    readgtkrc(themepath);
+    currenttheme = ui->theme->currentText();
     readSettings();
-    writeSettings();
-    progress3.setValue(100);
-    progress3.cancel();    
 }
