@@ -49,8 +49,15 @@ private:
     QProgressDialog progress3;
     QProgressDialog progress4;
     QColorDialog colors;
+    QString themepath;
+    QString icontheme;
+    QString wall1;
+    QString wall2;
+    QString wall3;
+    QString wall4;
     void readdirs();
-    void readgtkrc();
+    void readthemes();
+    void readgtkrc(QString themedir);
     QStringList fonts;
     QHash<QString, QString> variables;
     QHash<QString, QString> gtkrc;
@@ -82,7 +89,7 @@ private:
     managethemes* ManThemeWin;
 
 private slots:
-    void on_label_clicked();
+    void on_theme_currentIndexChanged(int index);
     void on_actionImport_theme_triggered();
     void on_actionExport_theme_triggered();
     void deletetheme();
