@@ -8,6 +8,18 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <source>Theme</source>
+        <translation>Teema</translation>
+    </message>
+    <message>
+        <source>Use theme&apos;s wallpapers</source>
+        <translation>Käytä teeman taustakuvia</translation>
+    </message>
+    <message>
+        <source>Keep my current wallpapers</source>
+        <translation>Pidä nykyiset taustakuvat</translation>
+    </message>
     <message>
         <source>Theme customizations applied!</source>
         <translation>Teeman kustomoinnit asetettu!</translation>
