@@ -9,33 +9,45 @@
         <translation>Customiser le thème</translation>
     </message>
     <message>
-        <source>Theme customizations applied!</source>
+        <source>Theme</source>
+        <translation>Thème</translation>
+    </message>
+    <message>
+        <source>Use theme&apos;s wallpapers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Restart the device to reload all theme elements and make all changes visible.</source>
+        <source>Keep my current wallpapers</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Theme customizations applied!</source>
+        <translation>Customisations du thème appliquer!</translation>
+    </message>
+    <message>
+        <source>Restart the device to reload all theme elements and make all changes visible.</source>
+        <translation>Redémarer le téléphone pour recharger tous les éléments du thème et voir toutes les modifications.</translation>
+    </message>
     <message>
         <source>Current theme: </source>
         <translation>Thème actuel: </translation>
     </message>
     <message>
         <source>Tap to change</source>
-        <translation type="unfinished"></translation>
+        <translation>Cliquer pour changer</translation>
     </message>
     <message>
         <source>Select folder containing the fonts you want to import</source>
-        <translation type="unfinished"></translation>
+        <translation>Séléctionner le dossier qui contient les fontes que vous voulez importer</translation>
     </message>
     <message>
         <source>Font import complete! Restart Theme Customizer to use new fonts.</source>
-        <translation type="unfinished"></translation>
+        <translation>Importation des fontes terminé! Redémarer &quot;Theme Customizer&quot; pour utiliser les nouvelles fontes.</translation>
     </message>
     <message>
         <source>No .ttf or .otf font files found under: </source>
-        <translation type="unfinished"></translation>
-    </message> 
+        <translation>Aucune fontes .ttf ou .otf trouvées dans: </translation>
+    </message>
     <message>
         <source>Use custom (fast) window transitions</source>
         <translation>Utiliser les transitions (rapide) de fenêtre customisées</translation>
@@ -111,19 +123,19 @@
     </message>
     <message>
         <source>Theme </source>
-        <translation type="unfinished"></translation>
+        <translation>Thème</translation>
     </message>
     <message>
         <source> already exists and cannot be overwritten!</source>
-        <translation type="unfinished"></translation>
+        <translation> existe déja et ne pas être écraser!</translation>
     </message>
     <message>
         <source>Overwrite existing theme?</source>
-        <translation type="unfinished"></translation>
+        <translation>Ecraser un thème existant?</translation>
     </message>
     <message>
         <source>Theme with this name already exists, do you want to overwrite it?</source>
-        <translation type="unfinished"></translation>
+        <translation>Un thème avec ce nom existe déja, voulez-vous l&apos;écraser?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
